.. _users-guide-index:

############
User's Guide
############

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    intro.rst
    installing.rst
    pyplot_tutorial.rst
    navigation_toolbar.rst
    customizing.rst
    shell.rst
    index_text.rst
    image_tutorial.rst
    artists.rst
    gridspec.rst
    tight_layout_guide.rst
    legend_guide.rst
    event_handling.rst
    transforms_tutorial.rst
    path_tutorial.rst
    annotations_guide.rst
    recipes.rst
    screenshots.rst
    whats_new.rst
    license.rst
    credits.rst



